@@ -20,6 +20,7 @@
 #define SCROLLKEEPER_H
 
 #include <libxml/tree.h>
+#include <sys/types.h>
 
 #define _(String) gettext (String)
 
@@ -29,8 +30,9 @@
  *
  */
 #define SCROLLKEEPERLOCALEDIR "/usr/share/locale"
-#define SCROLLKEEPERLOGFILE "/var/log/scrollkeeper.log"
-#define SCROLLKEEPERLOGFILE_ROT "/var/log/scrollkeeper.log.1"
+#define SCROLLKEEPERLOGFILE "/var/lib/log/scrollkeeper.log"
+#define SCROLLKEEPERLOGFILE_ROT "/var/lib/log/scrollkeeper.log.1"
+#define SCROLLKEEPER_OMF_DTD "/usr/share/xml/scrollkeeper/dtds/scrollkeeper-omf.dtd"
 #define PATHLEN		256
 
 /*
@@ -50,8 +52,8 @@
 #define SKOUT_LOG_QUIET         128
 
 #define SKOUT_QUIET     1       /* Output all messages                          */
-#define SKOUT_VERBOSE   2       /* Output VERBOSE, DEFAULT, and DEBUG messages  */
-#define SKOUT_DEFAULT   3       /* Output DEFAULT and DEBUG messages            */
+#define SKOUT_DEFAULT   2       /* Output DEFAULT, VERBSE, and DEBUG messages   */
+#define SKOUT_VERBOSE   3       /* Output VERBOSE and DEBUG messages            */
 #define SKOUT_DEBUG     4       /* Output DEBUG messages                        */
 
 /*
@@ -59,8 +61,10 @@
  * Functions.
  *
  */
-extern void sk_message(char, int, int, char *, char *, ...);
+extern int sk_mkdir_with_parents(char *, mode_t, char);
 extern void sk_warning(int, char *, char *, ...);
+extern void sk_message(char, int, int, char *, char *, ...);
+extern void sk_dtd_validation_message(char *, char *, ...);
 extern void check_ptr(void *, char *);
 extern char **sk_get_language_list(void);
 extern int is_file(char *);
@@ -68,7 +72,7 @@ extern int is_dir(char *);
 extern int apply_stylesheets(char *, char *, int, char **, char **, char);
 extern int copy_file(char *, char *);
 extern int install(char *, char *, char *, char);
-extern void create_database_directory(char *, char *);
+extern int create_database_directory(char *, char *, char);
 extern void uninstall(char *, char *, char);
 extern xmlDocPtr merge_locale_trees(char *, char *, char *);
 extern int update_doc_url_in_omf_file(char *, char *, char *);
